Index: sdk/lib/_internal/compiler/implementation/compile_time_constants.dart |
diff --git a/sdk/lib/_internal/compiler/implementation/compile_time_constants.dart b/sdk/lib/_internal/compiler/implementation/compile_time_constants.dart |
index cb1439a52e185e4b6b1b9d43f80902f52e73b632..6dd7695e7a72c87b264e6682db2a90bfb3d64bf5 100644 |
--- a/sdk/lib/_internal/compiler/implementation/compile_time_constants.dart |
+++ b/sdk/lib/_internal/compiler/implementation/compile_time_constants.dart |
@@ -221,12 +221,12 @@ class ConstantHandler extends CompilerTask { |
} |
/** |
* Returns a [List] of static non final fields that need to be initialized. |
* The list must be evaluated in order since the fields might depend on each |
* other. |
*/ |
- List<VariableElement> getStaticNonFinalFieldsForEmission() { |
- return initialVariableValues.keys.filter((element) { |
+ Iterable<VariableElement> getStaticNonFinalFieldsForEmission() { |
+ return initialVariableValues.keys.where((element) { |
return element.kind == ElementKind.FIELD |
&& !element.isInstanceMember() |
&& !element.modifiers.isFinal(); |
@@ -234,12 +234,12 @@ class ConstantHandler extends CompilerTask { |
} |
/** |
* Returns a [List] of static const fields that need to be initialized. The |
* list must be evaluated in order since the fields might depend on each |
* other. |
*/ |
- List<VariableElement> getStaticFinalFieldsForEmission() { |
- return initialVariableValues.keys.filter((element) { |
+ Iterable<VariableElement> getStaticFinalFieldsForEmission() { |
+ return initialVariableValues.keys.where((element) { |
return element.kind == ElementKind.FIELD |
&& !element.isInstanceMember() |
&& element.modifiers.isFinal(); |
@@ -221,12 +221,12 @@ class ConstantHandler extends CompilerTask { |
} |
/** |
- * Returns a [List] of static non final fields that need to be initialized. |
- * The list must be evaluated in order since the fields might depend on each |
- * other. |
+ * Returns an [Iterable] of static non final fields that need to be |
+ * initialized. The fields list must be evaluated in order since they might |
+ * depend on each other. |
*/ |
@@ -234,12 +234,12 @@ class ConstantHandler extends CompilerTask { |
} |
/** |
- * Returns a [List] of static const fields that need to be initialized. The |
- * list must be evaluated in order since the fields might depend on each |
+ * Returns an [Iterable] of static const fields that need to be initialized. |
+ * The fields must be evaluated in order since they might depend on each |
* other. |
*/ |